/* slurp-example-application.c
 *
 * Copyright (C) 2017 Julian Richen
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#define G_LOG_DOMAIN "slurp-example-application"

#include <gtk/gtk.h>

#include <slurp/slurp.h>
//#include <slurp-gtk/slurp-gtk.h>

static void
download_added_cb (GObject      *object,
                   GAsyncResult *result,
                   gpointer      user_data)
{
    SlurpDownload *download = SLURP_DOWNLOAD (object);
    gboolean retval = FALSE;
    GError *error = NULL;

    g_return_if_fail (SLURP_IS_DOWNLOAD (download));
    g_return_if_fail (G_IS_ASYNC_RESULT (result));
    g_return_if_fail (g_task_is_valid (result, download));

    retval = slurp_download_resource_finish (download, result, &error);

    if (!retval)
    {
        g_debug ("Error: %s", error->message);
    }
}

static void
activate (GtkApplication *application,
          gpointer        user_data)
{
    GtkWidget *window;
    GtkWidget *headerbar;

    window = gtk_application_window_new (application);
    gtk_window_set_title (GTK_WINDOW (window), "Slurp Example");
    gtk_window_set_default_size (GTK_WINDOW (window), 320, 480);

    headerbar = gtk_header_bar_new ();
    gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (headerbar), TRUE);
    gtk_header_bar_set_title (GTK_HEADER_BAR (headerbar), "Slurp Example");
    gtk_window_set_titlebar (GTK_WINDOW (window), headerbar);

    GtkWidget *progress = gtk_label_new ("0");
    gtk_container_add (GTK_CONTAINER (window), progress);

    SlurpResource *resource = NULL;
    SlurpDownload *download = NULL;
    GCancellable *cancellable = NULL;
    gchar *source;
    gchar *target;
    gboolean overwrite;

    source = "https://www.google.com/images/branding/googlelogo/1x/googlelogo_color_272x92dp.png";
    target = "/home/julian/Downloads/temp/";
    overwrite = FALSE;

    resource = g_object_new (SLURP_TYPE_RESOURCE,
                             "source", source,
                             "target", target,
                             "overwrite", overwrite,
                             NULL);

    g_print ("SOURCE: %s\n", slurp_resource_get_source (resource));
    g_print ("TARGET: %s\n", slurp_resource_get_target (resource));

    cancellable = g_cancellable_new ();
    download = slurp_download_new ();

    slurp_download_resource_async (download,
                                   resource,
                                   cancellable,
                                   download_added_cb,
                                   application);

    gtk_widget_show_all (window);
}

int
main (int    argc,
      char **argv)
{
    GtkApplication *application;
    int status;

    application = gtk_application_new ("org.gnome.slurp.application",
                                       G_APPLICATION_FLAGS_NONE);

    g_signal_connect (application, "activate", G_CALLBACK (activate), NULL);

    status = g_application_run (G_APPLICATION (application), argc, argv);

    g_object_unref (application);

    return status;
}
